package com.cpms.project.process.mapper;

import java.util.List;
import com.cpms.project.process.domain.TSisRecord;

/**
 * sis RecordMapper接口
 * 
 * @author admin
 * @date 2024-05-22
 */
public interface TSisRecordMapper 
{
    /**
     * 查询sis Record
     * 
     * @param id sis Record主键
     * @return sis Record
     */
    public TSisRecord selectTSisRecordById(Long id);

    /**
     * 查询sis Record列表
     * 
     * @param tSisRecord sis Record
     * @return sis Record集合
     */
    public List<TSisRecord> selectTSisRecordList(TSisRecord tSisRecord);

    /**
     * 新增sis Record
     * 
     * @param tSisRecord sis Record
     * @return 结果
     */
    public int insertTSisRecord(TSisRecord tSisRecord);

    /**
     * 修改sis Record
     * 
     * @param tSisRecord sis Record
     * @return 结果
     */
    public int updateTSisRecord(TSisRecord tSisRecord);

    /**
     * 删除sis Record
     * 
     * @param id sis Record主键
     * @return 结果
     */
    public int deleteTSisRecordById(Long id);

    /**
     * 批量删除sis Record
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTSisRecordByIds(Long[] ids);
}
